@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AdminCustomerUser.pm - to add/update/delete customer user and preferences
-# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: AdminCustomerUser.pm,v 1.87 2010/12/09 00:01:02 mp Exp $
+# $Id: AdminCustomerUser.pm,v 1.99.2.1 2012/09/06 08:30:36 mh Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -20,7 +20,7 @@ use Kernel::System::Valid;
 use Kernel::System::CheckItem;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.87 $) [1];
+$VERSION = qw($Revision: 1.99.2.1 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -38,6 +38,8 @@ sub new {
             $Self->{LayoutObject}->FatalError( Message => "Got no $Needed!" );
         }
     }
+
+    # create additonal objects
     $Self->{CustomerUserObject}    = Kernel::System::CustomerUser->new(%Param);
     $Self->{CustomerCompanyObject} = Kernel::System::CustomerCompany->new(%Param);
     $Self->{ValidObject}           = Kernel::System::Valid->new(%Param);
@@ -47,14 +49,17 @@ sub new {
 
 sub Run {
     my ( $Self, %Param ) = @_;
-    my $NavBar = '';
-    my $Nav    = $Self->{ParamObject}->GetParam( Param => 'Nav' ) || '';
+
+    my $Nav    = $Self->{ParamObject}->GetParam( Param => 'Nav' )    || '';
     my $Source = $Self->{ParamObject}->GetParam( Param => 'Source' ) || 'CustomerUser';
-    my $Search = $Self->{ParamObject}->GetParam( Param => 'Search' ) || '*';
+    my $Search = $Self->{ParamObject}->GetParam( Param => 'Search' );
+    $Search
+        ||= $Self->{ConfigObject}->Get('AdminCustomerUser::RunInitialWildcardSearch') ? '*' : '';
 
     #create local object
     my $CheckItemObject = Kernel::System::CheckItem->new( %{$Self} );
 
+    my $NavBar = '';
     if ( $Nav eq 'None' ) {
         $NavBar = $Self->{LayoutObject}->Header( Type => 'Small' );
     }
@@ -83,6 +88,7 @@ sub Run {
         else {
             $Output .= $Self->{LayoutObject}->Footer();
         }
+
         return $Output;
     }
 
@@ -120,16 +126,15 @@ sub Run {
 
         # get user data
         my %UserData = $Self->{CustomerUserObject}->CustomerUserDataGet( User => $User );
-        my $Output = $NavBar
-            . $Self->_Edit(
+        my $Output = $NavBar;
+        $Output .= $Self->_Edit(
             Nav    => $Nav,
             Action => 'Change',
             Source => $Source,
-            Nav    => $Nav,
             Search => $Search,
             ID     => $User,
             %UserData,
-            );
+        );
 
         if ( $Nav eq 'None' ) {
             $Output .= $Self->{LayoutObject}->Footer( Type => 'Small' );
@@ -137,6 +142,7 @@ sub Run {
         else {
             $Output .= $Self->{LayoutObject}->Footer();
         }
+
         return $Output;
     }
 
@@ -144,6 +150,10 @@ sub Run {
     # change action
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'ChangeAction' ) {
+
+        # challenge token check for write action
+        $Self->{LayoutObject}->ChallengeTokenCheck();
+
         my $Note = '';
         my ( %GetParam, %Errors );
         for my $Entry ( @{ $Self->{ConfigObject}->Get($Source)->{Map} } ) {
@@ -228,6 +238,7 @@ sub Run {
                     else {
                         $Output .= $Self->{LayoutObject}->Footer();
                     }
+
                     return $Output;
                 }
             }
@@ -242,7 +253,6 @@ sub Run {
         $Output .= $Self->_Edit(
             Nav    => $Nav,
             Action => 'Change',
-            Nav    => $Nav,
             Source => $Source,
             Search => $Search,
             Errors => \%Errors,
@@ -255,6 +265,7 @@ sub Run {
         else {
             $Output .= $Self->{LayoutObject}->Footer();
         }
+
         return $Output;
     }
 
@@ -264,14 +275,14 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'Add' ) {
         my %GetParam;
         $GetParam{UserLogin} = $Self->{ParamObject}->GetParam( Param => 'UserLogin' ) || '';
-        my $Output = $NavBar
-            . $Self->_Edit(
+        my $Output = $NavBar;
+        $Output .= $Self->_Edit(
             Nav    => $Nav,
             Action => 'Add',
             Source => $Source,
             Search => $Search,
             %GetParam,
-            );
+        );
 
         if ( $Nav eq 'None' ) {
             $Output .= $Self->{LayoutObject}->Footer( Type => 'Small' );
@@ -279,6 +290,7 @@ sub Run {
         else {
             $Output .= $Self->{LayoutObject}->Footer();
         }
+
         return $Output;
     }
 
@@ -286,11 +298,22 @@ sub Run {
     # add action
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'AddAction' ) {
+
+        # challenge token check for write action
+        $Self->{LayoutObject}->ChallengeTokenCheck();
+
         my $Note = '';
         my ( %GetParam, %Errors );
+
+        my $AutoLoginCreation = $Self->{ConfigObject}->Get($Source)->{AutoLoginCreation};
+
+        ENTRY:
         for my $Entry ( @{ $Self->{ConfigObject}->Get($Source)->{Map} } ) {
             $GetParam{ $Entry->[0] } = $Self->{ParamObject}->GetParam( Param => $Entry->[0] ) || '';
 
+            # don't validate UserLogin if AutoLoginCreation is configured
+            next ENTRY if ( $AutoLoginCreation && $Entry->[0] eq 'UserLogin' );
+
             # check mandatory fields
             if ( !$GetParam{ $Entry->[0] } && $Entry->[4] ) {
                 $Errors{ $Entry->[0] . 'Invalid' } = 'ServerError';
@@ -387,7 +410,7 @@ sub Run {
                     my $UserQuote     = $Self->{LayoutObject}->Ascii2Html( Text => $User );
                     if ( $Self->{ConfigObject}->Get('Frontend::Module')->{AgentTicketPhone} ) {
                         $URL
-                            .= "<a href=\"\$Env{\"CGIHandle\"}?Action=AgentTicketPhone;Subaction=StoreNew;ExpandCustomerName=2;CustomerUser=$UserHTMLQuote\">"
+                            .= "<a href=\"\$Env{\"CGIHandle\"}?Action=AgentTicketPhone;Subaction=StoreNew;ExpandCustomerName=2;CustomerUser=$UserHTMLQuote;\$QEnv{\"ChallengeTokenParam\"}\">"
                             . $Self->{LayoutObject}->{LanguageObject}->Get('New phone ticket')
                             . "</a>";
                     }
@@ -396,7 +419,7 @@ sub Run {
                             $URL .= " - ";
                         }
                         $URL
-                            .= "<a href=\"\$Env{\"CGIHandle\"}?Action=AgentTicketEmail;Subaction=StoreNew;ExpandCustomerName=2;CustomerUser=$UserHTMLQuote\">"
+                            .= "<a href=\"\$Env{\"CGIHandle\"}?Action=AgentTicketEmail;Subaction=StoreNew;ExpandCustomerName=2;CustomerUser=$UserHTMLQuote;\$QEnv{\"ChallengeTokenParam\"}\">"
                             . $Self->{LayoutObject}->{LanguageObject}->Get('New email ticket')
                             . "</a>";
                     }
@@ -429,6 +452,7 @@ sub Run {
                     else {
                         $Output .= $Self->{LayoutObject}->Footer();
                     }
+
                     return $Output;
                 }
             }
@@ -438,12 +462,10 @@ sub Run {
         }
 
         # something has gone wrong
-        my $Output = $NavBar;
-        $Output .= $Note;
+        my $Output = $NavBar . $Note;
         $Output .= $Self->_Edit(
             Nav    => $Nav,
             Action => 'Add',
-            Nav    => $Nav,
             Source => $Source,
             Search => $Search,
             Errors => \%Errors,
@@ -456,6 +478,7 @@ sub Run {
         else {
             $Output .= $Self->{LayoutObject}->Footer();
         }
+
         return $Output;
     }
 
@@ -479,6 +502,7 @@ sub Run {
         else {
             $Output .= $Self->{LayoutObject}->Footer();
         }
+
         return $Output;
     }
 }
@@ -486,14 +510,6 @@ sub Run {
 sub _Overview {
     my ( $Self, %Param ) = @_;
 
-    my $Output = '';
-
-    # build source string
-    $Param{SourceOption} = $Self->{LayoutObject}->BuildSelection(
-        Data       => { $Self->{CustomerUserObject}->CustomerSourceList() },
-        Name       => 'Source',
-        SelectedID => $Param{Source} || '',
-    );
     $Self->{LayoutObject}->Block(
         Name => 'Overview',
         Data => \%Param,
@@ -504,11 +520,26 @@ sub _Overview {
         Name => 'ActionSearch',
         Data => \%Param,
     );
-    $Self->{LayoutObject}->Block(
-        Name => 'ActionAdd',
-        Data => \%Param,
+
+    # get writable data sources
+    my %CustomerSource = $Self->{CustomerUserObject}->CustomerSourceList(
+        ReadOnly => 0,
     );
 
+    # only show Add option if we have at least one writable backend
+    if ( scalar keys %CustomerSource ) {
+        $Param{SourceOption} = $Self->{LayoutObject}->BuildSelection(
+            Data       => { %CustomerSource, },
+            Name       => 'Source',
+            SelectedID => $Param{Source} || '',
+        );
+
+        $Self->{LayoutObject}->Block(
+            Name => 'ActionAdd',
+            Data => \%Param,
+        );
+    }
+
     $Self->{LayoutObject}->Block(
         Name => 'OverviewHeader',
         Data => {},
@@ -590,13 +621,6 @@ sub _Edit {
 
     my $Output = '';
 
-    # build source string
-    $Param{CompanyOption} = $Self->{LayoutObject}->BuildSelection(
-        Data       => { $Self->{CustomerCompanyObject}->CustomerCompanyList() },
-        Name       => 'CustomerID',
-        SelectedID => $Param{CustomerID},
-    );
-
     $Self->{LayoutObject}->Block(
         Name => 'Overview',
         Data => \%Param,
@@ -634,7 +658,7 @@ sub _Edit {
         # check if login auto creation
         if (
             $Self->{ConfigObject}->Get( $Param{Source} )->{AutoLoginCreation}
-            && $Entry->[0] =~ /^UserLogin$/
+            && $Entry->[0] eq 'UserLogin'
             )
         {
             $Block = 'InputHidden';
@@ -660,6 +684,9 @@ sub _Edit {
             $Param{RequiredLabelCharacter} = '';
         }
 
+        # set empty string
+        $Param{Errors}->{ $Entry->[0] . 'Invalid' } ||= '';
+
         # add class to validate emails
         if ( $Entry->[0] eq 'UserEmail' ) {
             $Param{RequiredClass} .= ' Validate_Email';
@@ -680,18 +707,20 @@ sub _Edit {
 
             # make sure the encoding stamp is set
             for my $Key ( keys %{$SelectionsData} ) {
-                $SelectionsData->{$Key} = $Self->{EncodeObject}->Encode( $SelectionsData->{$Key} );
+                $SelectionsData->{$Key}
+                    = $Self->{EncodeObject}->EncodeInput( $SelectionsData->{$Key} );
             }
 
-            $Param{Option} = $Self->{LayoutObject}->BuildSelection(
-                Data                => $SelectionsData,
-                Name                => $Entry->[0],
-                LanguageTranslation => 0,
-                SelectedID          => $Param{ $Entry->[0] },
-                Class => $Param{RequiredClass} . ' ' . $Param{Errors}->{ $Entry->[0] . 'Invalid' }
-                    || '',
-            );
+            $Param{RequiredClass} ||= '';
 
+            # build option string
+            $Param{Option} = $Self->{LayoutObject}->BuildSelection(
+                Data        => $SelectionsData,
+                Name        => $Entry->[0],
+                Translation => 0,
+                SelectedID  => $Param{ $Entry->[0] },
+                Class => $Param{RequiredClass} . ' ' . $Param{Errors}->{ $Entry->[0] . 'Invalid' },
+            );
         }
         elsif ( $Entry->[0] =~ /^ValidID/i ) {
 
@@ -715,13 +744,12 @@ sub _Edit {
             && $Self->{ConfigObject}->Get( $Param{Source} )->{CustomerCompanySupport}
             )
         {
-            my %Company     = ();
             my %CompanyList = (
                 $Self->{CustomerCompanyObject}->CustomerCompanyList(),
                 '' => '-',
             );
             if ( $Param{ $Entry->[0] } ) {
-                %Company = $Self->{CustomerCompanyObject}->CustomerCompanyGet(
+                my %Company = $Self->{CustomerCompanyObject}->CustomerCompanyGet(
                     CustomerID => $Param{ $Entry->[0] },
                 );
                 if ( !%Company ) {
@@ -804,6 +832,7 @@ sub _Edit {
             my %Data;
             my %Preferences = %{ $Self->{ConfigObject}->Get('CustomerPreferencesGroups') };
             for my $Group ( keys %Preferences ) {
+                $Preferences{$Group}->{Column} ||= '';
                 if ( $Preferences{$Group}->{Column} eq $Column ) {
                     if ( $Data{ $Preferences{$Group}->{Prio} } ) {
                         for ( 1 .. 151 ) {
