@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AgentTicketActionCommon.pm - common file for several modules
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.org/
 # --
-# $Id: AgentTicketActionCommon.pm,v 1.81.2.5 2012/06/15 21:29:26 cr Exp $
+# $Id: AgentTicketActionCommon.pm,v 1.81.2.10 2013/01/30 00:00:06 cr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -906,7 +906,7 @@ sub Run {
                     Data         => $Owners,
                     SelectedID   => $GetParam{NewOwnerID},
                     Translation  => 0,
-                    PossibleNone => 0,
+                    PossibleNone => 1,
                     Max          => 100,
                 },
                 {
@@ -914,7 +914,7 @@ sub Run {
                     Data         => $OldOwners,
                     SelectedID   => $GetParam{OldOwnerID},
                     Translation  => 0,
-                    PossibleNone => 0,
+                    PossibleNone => 1,
                     Max          => 100,
                 },
                 {
@@ -926,11 +926,12 @@ sub Run {
                     Max          => 100,
                 },
                 {
-                    Name        => 'NewStateID',
-                    Data        => $NextStates,
-                    SelectedID  => $GetParam{NewStateID},
-                    Translation => 1,
-                    Max         => 100,
+                    Name         => 'NewStateID',
+                    Data         => $NextStates,
+                    SelectedID   => $GetParam{NewStateID},
+                    Translation  => 1,
+                    PossibleNone => $Self->{Config}->{StateDefault} ? 0 : 1,
+                    Max          => 100,
                 },
                 {
                     Name         => 'NewPriorityID',
@@ -1199,12 +1200,12 @@ sub _Mask {
         # get old owner
         my @OldUserInfo = $Self->{TicketObject}->TicketOwnerList( TicketID => $Self->{TicketID} );
         $Param{OwnerStrg} = $Self->{LayoutObject}->BuildSelection(
-            Data       => \%ShownUsers,
-            SelectedID => $Param{NewOwnerID},
-            Name       => 'NewOwnerID',
-            Class      => $Param{NewOwnerInvalid} || ' ',
-            Size       => 1,
-
+            Data         => \%ShownUsers,
+            SelectedID   => $Param{NewOwnerID},
+            Name         => 'NewOwnerID',
+            Class        => $Param{NewOwnerInvalid} || ' ',
+            Size         => 1,
+            PossibleNone => 1,
         );
         my %UserHash;
         if (@OldUserInfo) {
@@ -1216,9 +1217,6 @@ sub _Mask {
                 $Counter++;
             }
         }
-        if ( !%UserHash ) {
-            $UserHash{''} = '-';
-        }
         my $OldOwnerSelectedID = '';
         if ( $Param{OldOwnerID} ) {
             $OldOwnerSelectedID = $Param{OldOwnerID};
@@ -1229,11 +1227,11 @@ sub _Mask {
 
         # build string
         $Param{OldOwnerStrg} = $Self->{LayoutObject}->BuildSelection(
-            Data       => \%UserHash,
-            SelectedID => $OldOwnerSelectedID,
-            Name       => 'OldOwnerID',
-            Class      => $Param{OldOwnerInvalid} || ' ',
-
+            Data         => \%UserHash,
+            SelectedID   => $OldOwnerSelectedID,
+            Name         => 'OldOwnerID',
+            Class        => $Param{OldOwnerInvalid} || ' ',
+            PossibleNone => 1,
         );
         if ( $Param{NewOwnerType} && $Param{NewOwnerType} eq 'Old' ) {
             $Param{'NewOwnerType::Old'} = 'checked = "checked"';
@@ -1290,9 +1288,6 @@ sub _Mask {
             TicketID => $Self->{TicketID},
             UserID   => $Self->{UserID},
         );
-        if ( !$Self->{Config}->{StateDefault} ) {
-            $StateList{''} = '-';
-        }
         if ( !$Param{NewStateID} ) {
             if ( $Self->{Config}->{StateDefault} ) {
                 $State{SelectedValue} = $Self->{Config}->{StateDefault};
@@ -1304,8 +1299,9 @@ sub _Mask {
 
         # build next states string
         $Param{StateStrg} = $Self->{LayoutObject}->BuildSelection(
-            Data => \%StateList,
-            Name => 'NewStateID',
+            Data         => \%StateList,
+            Name         => 'NewStateID',
+            PossibleNone => $Self->{Config}->{StateDefault} ? 0 : 1,
             %State,
         );
         $Self->{LayoutObject}->Block(
@@ -1405,12 +1401,14 @@ sub _Mask {
             for my $UserID ( keys %MemberList ) {
                 $ShownUsers{$UserID} = $AllGroupsMembers{$UserID};
             }
+            my $InformAgentSize = $Self->{ConfigObject}->Get('Ticket::Frontend::InformAgentMaxSize')
+                || 3;
             $Param{OptionStrg} = $Self->{LayoutObject}->BuildSelection(
                 Data       => \%ShownUsers,
                 SelectedID => $Self->{InformUserID},
                 Name       => 'InformUserID',
                 Multiple   => 1,
-                Size       => 3,
+                Size       => $InformAgentSize,
             );
             $Self->{LayoutObject}->Block(
                 Name => 'InformAgent',
@@ -1440,12 +1438,14 @@ sub _Mask {
                 $Counter++;
             }
 
+            my $InvolvedAgentSize
+                = $Self->{ConfigObject}->Get('Ticket::Frontend::InvolvedAgentMaxSize') || 3;
             $Param{InvolvedAgentStrg} = $Self->{LayoutObject}->BuildSelection(
                 Data       => \%UserHash,
                 SelectedID => $Self->{InvolvedUserID},
                 Name       => 'InvolvedUserID',
                 Multiple   => 1,
-                Size       => 3,
+                Size       => $InvolvedAgentSize,
             );
             $Self->{LayoutObject}->Block(
                 Name => 'InvolvedAgent',
@@ -1661,9 +1661,6 @@ sub _GetOldOwners {
             $Counter++;
         }
     }
-    if ( !%UserHash ) {
-        $UserHash{''} = '-';
-    }
 
     # workflow
     my $ACL = $Self->{TicketObject}->TicketAcl(
@@ -1689,12 +1686,15 @@ sub _GetServices {
     my $DefaultServiceUnknownCustomer
         = $Self->{ConfigObject}->Get('Ticket::Service::Default::UnknownCustomer');
 
+    # check if no CustomerUserID is selected
+    # if $DefaultServiceUnknownCustomer = 0 leave CustomerUserID empty, it will not get any services
+    # if $DefaultServiceUnknownCustomer = 1 set CustomerUserID to get default services
+    if ( !$Param{CustomerUserID} && $DefaultServiceUnknownCustomer ) {
+        $Param{CustomerUserID} = '<DEFAULT>';
+    }
+
     # get service list
-    if (
-        ( defined $Param{CustomerUserID} && $Param{CustomerUserID} )
-        || $DefaultServiceUnknownCustomer
-        )
-    {
+    if ( $Param{CustomerUserID} ) {
         %Service = $Self->{TicketObject}->TicketServiceList(
             %Param,
             Action => $Self->{Action},
