@@ -2,7 +2,7 @@
 # Kernel/Modules/AgentTicketCompose.pm - to compose and send a message
 # Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: AgentTicketCompose.pm,v 1.160 2012/01/27 12:27:35 mb Exp $
+# $Id: AgentTicketCompose.pm,v 1.164.2.2 2012/09/26 21:32:50 mh Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -27,7 +27,7 @@ use Kernel::System::VariableCheck qw(:all);
 use Mail::Address;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.160 $) [1];
+$VERSION = qw($Revision: 1.164.2.2 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -190,6 +190,7 @@ sub Run {
     my $Selected = $Self->{ParamObject}->GetParam( Param => 'CustomerSelected' ) || '';
 
     if ($CustomersNumber) {
+
         my $CustomerCounter = 1;
         for my $Count ( 1 ... $CustomersNumber ) {
             my $CustomerElement
@@ -201,7 +202,12 @@ sub Run {
                 || '';
             if ($CustomerElement) {
 
-                $GetParam{To} .= $CustomerElement . ',';
+                if ( $GetParam{To} ) {
+                    $GetParam{To} .= ', ' . $CustomerElement;
+                }
+                else {
+                    $GetParam{To} = $CustomerElement;
+                }
 
                 # check email address
                 my $CustomerErrorMsg = 'CustomerGenericServerErrorMsg';
@@ -221,7 +227,7 @@ sub Run {
                 }
 
                 my $CustomerDisabled = '';
-                my $CountAux         = $Count;
+                my $CountAux         = $CustomerCounter++;
                 if ( $CustomerError ne '' ) {
                     $CustomerDisabled = 'disabled="disabled"';
                     $CountAux         = $Count . 'Error';
@@ -251,6 +257,7 @@ sub Run {
         = $Self->{ParamObject}->GetParam( Param => 'CustomerTicketCounterCcCustomer' ) || 0;
 
     if ($CustomersNumberCc) {
+        my $CustomerCounterCc = 1;
         for my $Count ( 1 ... $CustomersNumberCc ) {
             my $CustomerElementCc
                 = $Self->{ParamObject}->GetParam( Param => 'CcCustomerTicketText_' . $Count );
@@ -262,7 +269,12 @@ sub Run {
 
             if ($CustomerElementCc) {
 
-                $GetParam{Cc} .= $CustomerElementCc . ',';
+                if ( $GetParam{Cc} ) {
+                    $GetParam{Cc} .= ', ' . $CustomerElementCc;
+                }
+                else {
+                    $GetParam{Cc} = $CustomerElementCc;
+                }
 
                 # check email address
                 my $CustomerErrorMsgCc = 'CustomerGenericServerErrorMsg';
@@ -282,7 +294,7 @@ sub Run {
                 }
 
                 my $CustomerDisabledCc = '';
-                my $CountAuxCc         = $Count;
+                my $CountAuxCc         = $CustomerCounterCc++;
                 if ( $CustomerErrorCc ne '' ) {
                     $CustomerDisabledCc = 'disabled="disabled"';
                     $CountAuxCc         = $Count . 'Error';
@@ -311,6 +323,7 @@ sub Run {
         = $Self->{ParamObject}->GetParam( Param => 'CustomerTicketCounterBccCustomer' ) || 0;
 
     if ($CustomersNumberBcc) {
+        my $CustomerCounterBcc = 1;
         for my $Count ( 1 ... $CustomersNumberBcc ) {
             my $CustomerElementBcc
                 = $Self->{ParamObject}->GetParam( Param => 'BccCustomerTicketText_' . $Count );
@@ -323,7 +336,12 @@ sub Run {
 
             if ($CustomerElementBcc) {
 
-                $GetParam{Bcc} .= $CustomerElementBcc . ',';
+                if ( $GetParam{Bcc} ) {
+                    $GetParam{Bcc} .= ', ' . $CustomerElementBcc;
+                }
+                else {
+                    $GetParam{Bcc} = $CustomerElementBcc;
+                }
 
                 # check email address
                 my $CustomerErrorMsgBcc = 'CustomerGenericServerErrorMsg';
@@ -343,7 +361,7 @@ sub Run {
                 }
 
                 my $CustomerDisabledBcc = '';
-                my $CountAuxBcc         = $Count;
+                my $CountAuxBcc         = $CustomerCounterBcc++;
                 if ( $CustomerErrorBcc ne '' ) {
                     $CustomerDisabledBcc = 'disabled="disabled"';
                     $CountAuxBcc         = $Count . 'Error';
@@ -387,12 +405,12 @@ sub Run {
     # convert dynamic field values into a structure for ACLs
     my %DynamicFieldACLParameters;
     DYNAMICFIELD:
-    for my $DynamcField ( keys %DynamicFieldValues ) {
-        next DYNAMICFIELD if !$DynamcField;
-        next DYNAMICFIELD if !$DynamicFieldValues{$DynamcField};
+    for my $DynamicField ( keys %DynamicFieldValues ) {
+        next DYNAMICFIELD if !$DynamicField;
+        next DYNAMICFIELD if !$DynamicFieldValues{$DynamicField};
 
-        $DynamicFieldACLParameters{ 'DynamicField_' . $DynamcField }
-            = $DynamicFieldValues{$DynamcField};
+        $DynamicFieldACLParameters{ 'DynamicField_' . $DynamicField }
+            = $DynamicFieldValues{$DynamicField};
     }
     $GetParam{DynamicField} = \%DynamicFieldACLParameters;
 
@@ -691,13 +709,15 @@ sub Run {
 
         # get recipients
         my $Recipients = '';
+        LINE:
         for my $Line (qw(To Cc Bcc)) {
-            if ( $GetParam{$Line} ) {
-                if ($Recipients) {
-                    $Recipients .= ',';
-                }
-                $Recipients .= $GetParam{$Line};
+
+            next LINE if !$GetParam{$Line};
+
+            if ($Recipients) {
+                $Recipients .= ', ';
             }
+            $Recipients .= $GetParam{$Line};
         }
 
         my $MimeType = 'text/plain';
@@ -1165,7 +1185,11 @@ sub Run {
                 # replace To with customers database address
                 if ( $Self->{ConfigObject}->Get('Ticket::Frontend::ComposeReplaceSenderAddress') ) {
                     $Output .= $Self->{LayoutObject}->Notify(
-                        Data => "To: ($Data{To}) replaced with database email!",
+                        Data => $Self->{LayoutObject}->{LanguageObject}->Get(
+                            'Address %s replaced with registered customer address.", "'
+                                . $Data{ToEmail}
+                        ),
+
                     );
                     $Data{To} = $Customer{UserEmail};
                 }
@@ -1173,7 +1197,7 @@ sub Run {
                 # add customers database address to Cc
                 else {
                     $Output .= $Self->{LayoutObject}->Notify(
-                        Data => "Cc: ($Customer{UserEmail}) added database email!",
+                        Info => "Customer automatically added in Cc.",
                     );
                     if ( $Data{Cc} ) {
                         $Data{Cc} .= ', ' . $Customer{UserEmail};
