@@ -1,8 +1,8 @@
 # --
 # Kernel/Output/HTML/ArticleCheckSMIME.pm
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.org/
 # --
-# $Id: ArticleCheckSMIME.pm,v 1.20.6.7 2012/05/04 09:05:35 mg Exp $
+# $Id: ArticleCheckSMIME.pm,v 1.28.2.2 2013/02/08 22:52:41 cr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -18,7 +18,7 @@ use Kernel::System::Crypt;
 use Kernel::System::EmailParser;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.20.6.7 $) [1];
+$VERSION = qw($Revision: 1.28.2.2 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -160,7 +160,7 @@ sub Check {
                 my @PrivateKeysResult
                     = $Self->{CryptObject}->PrivateSearch( Search => $EmailAddress, );
                 for my $Cert (@PrivateKeysResult) {
-                    $PrivateKeys{ $Cert->{Hash} } = $Cert;
+                    $PrivateKeys{ $Cert->{Filename} } = $Cert;
                 }
             }
 
@@ -328,6 +328,25 @@ sub Check {
                     );
                 }
             }
+
+            # output signature verification errors
+            elsif (
+                %SignCheck
+                && !$SignCheck{SignatureFound}
+                && !$SignCheck{Successful}
+                && !$SignCheck{Content}
+                )
+            {
+                # return result
+                push(
+                    @Return,
+                    {
+                        Key   => 'Signed',
+                        Value => $SignCheck{Message},
+                        %SignCheck,
+                    }
+                );
+            }
         }
     }
 
