@@ -2,7 +2,7 @@
 # Kernel/System/DynamicField/Backend/Multiselect.pm - Delegate for DynamicField Multiselect backend
 # Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: Multiselect.pm,v 1.49 2012/03/20 16:27:56 mg Exp $
+# $Id: Multiselect.pm,v 1.51.2.2 2012/12/20 16:01:27 cr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -19,7 +19,7 @@ use Kernel::System::DynamicFieldValue;
 use Kernel::System::DynamicField::Backend::BackendCommon;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.49 $) [1];
+$VERSION = qw($Revision: 1.51.2.2 $) [1];
 
 =head1 NAME
 
@@ -108,8 +108,13 @@ sub ValueSet {
     }
 
     my @ValueText;
-    for my $Item (@Values) {
-        push @ValueText, { ValueText => $Item };
+    if ( IsArrayRefWithData( \@Values ) ) {
+        for my $Item (@Values) {
+            push @ValueText, { ValueText => $Item };
+        }
+    }
+    else {
+        push @ValueText, { ValueText => '' };
     }
 
     my $Success = $Self->{DynamicFieldValueObject}->ValueSet(
@@ -618,15 +623,14 @@ sub SearchFieldRender {
     my $SelectionData = $FieldConfig->{PossibleValues};
 
     # get historical values from database
-    my $HistoricalValues = $Self->{DynamicFieldValueObject}->HistoricalValueGet(
-        FieldID   => $Param{DynamicFieldConfig}->{ID},
-        ValueType => 'Text,',
-    );
+    my $HistoricalValues = $Self->HistoricalValuesGet(%Param);
 
     # add historic values to current values (if they don't exist anymore)
-    for my $Key ( keys %{$HistoricalValues} ) {
-        if ( !$SelectionData->{$Key} ) {
-            $SelectionData->{$Key} = $HistoricalValues->{$Key}
+    if ( IsHashRefWithData($HistoricalValues) ) {
+        for my $Key ( keys %{$HistoricalValues} ) {
+            if ( !$SelectionData->{$Key} ) {
+                $SelectionData->{$Key} = $HistoricalValues->{$Key}
+            }
         }
     }
 
@@ -889,16 +893,31 @@ sub RandomValueSet {
 sub IsMatchable {
     my ( $Self, %Param ) = @_;
 
-    return 0;
+    return 1;
 }
 
 sub ObjectMatch {
     my ( $Self, %Param ) = @_;
 
-    my $FieldName = $Param{DynamicFieldConfig}->{Name};
+    my $FieldName = 'DynamicField_' . $Param{DynamicFieldConfig}->{Name};
 
-    # not supported
-    return 0;
+    # the attribute must be an array
+    return 0 if !IsArrayRefWithData( $Param{ObjectAttributes}->{$FieldName} );
+
+    my $Match;
+
+    # search in all values for this attribute
+    VALUE:
+    for my $AttributeValue ( @{ $Param{ObjectAttributes}->{$FieldName} } ) {
+
+        # only need to match one
+        if ( $Param{Value} eq $AttributeValue ) {
+            $Match = 1;
+            last VALUE;
+        }
+    }
+
+    return $Match;
 }
 
 sub AJAXPossibleValuesGet {
@@ -924,6 +943,19 @@ sub AJAXPossibleValuesGet {
     return \%PossibleValues;
 }
 
+sub HistoricalValuesGet {
+    my ( $Self, %Param ) = @_;
+
+    # get historical values from database
+    my $HistoricalValues = $Self->{DynamicFieldValueObject}->HistoricalValueGet(
+        FieldID   => $Param{DynamicFieldConfig}->{ID},
+        ValueType => 'Text',
+    );
+
+    # retrun the historical values from database
+    return $HistoricalValues;
+}
+
 1;
 
 =back
