@@ -1,8 +1,8 @@
 # --
 # Kernel/System/EmailParser.pm - the global email parser module
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: EmailParser.pm,v 1.104.2.1 2011-07-28 15:09:09 en Exp $
+# $Id: EmailParser.pm,v 1.107.2.1 2012/11/29 12:42:28 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -24,7 +24,7 @@ use MIME::Words qw(:all);
 use Mail::Address;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.104.2.1 $) [1];
+$VERSION = qw($Revision: 1.107.2.1 $) [1];
 
 =head1 NAME
 
@@ -152,6 +152,9 @@ sub new {
         # create MIME::Parser object and get message body or body of first attachment
         my $Parser = MIME::Parser->new();
         $Parser->output_to_core('ALL');
+
+        # Keep nested messages as attachments (see bug#1970).
+        $Parser->extract_nested_messages(0);
         $Self->{ParserParts} = $Parser->parse_data( $Self->{Email}->as_string() );
     }
     else {
@@ -447,27 +450,15 @@ sub GetReturnContentType {
     my $Self = shift;
 
     my $ContentType = $Self->GetContentType();
-    if ( $Self->{EncodeObject}->CharsetInternal() ) {
-        my $InternalCharset = $Self->{EncodeObject}->CharsetInternal();
-        $ContentType =~ s/(charset=)(.*)/$1$InternalCharset/ig;
-
-        # debug
-        if ( $Self->{Debug} > 0 ) {
-            $Self->{LogObject}->Log(
-                Priority => 'debug',
-                Message  => "Changed ContentType from '"
-                    . $Self->GetContentType()
-                    . "' to '$ContentType'.",
-            );
-        }
-        return $ContentType;
-    }
+    $ContentType =~ s/(charset=)(.*)/$1utf-8/ig;
 
     # debug
     if ( $Self->{Debug} > 0 ) {
         $Self->{LogObject}->Log(
             Priority => 'debug',
-            Message  => 'Changed no ContentType',
+            Message  => "Changed ContentType from '"
+                . $Self->GetContentType()
+                . "' to '$ContentType'.",
         );
     }
     return $ContentType;
@@ -487,11 +478,7 @@ Returns the charset of the new message body "Charset"
 sub GetReturnCharset {
     my $Self = shift;
 
-    if ( $Self->{EncodeObject}->CharsetInternal() ) {
-        return $Self->{EncodeObject}->CharsetInternal();
-    }
-
-    return $Self->GetCharset();
+    return 'utf-8';
 }
 
 =item GetMessageBody()
@@ -540,7 +527,7 @@ sub GetMessageBody {
             $Self->{MessageBody} = $BodyStrg;
         }
 
-        # check if it's juat a html email (store it as attachment and add text/plain)
+        # check if the mail contains only HTML (store it as attachment and add text/plain)
         $Self->CheckMessageBody();
 
         # return message body
@@ -555,7 +542,7 @@ sub GetMessageBody {
             );
         }
 
-        # check if there is an valid attachment there, if yes, return
+        # check if there is a valid attachment there, if yes, return
         # first attachment (normally text/plain) as message body
         my @Attachments = $Self->GetAttachments();
         if ( @Attachments > 0 ) {
@@ -587,7 +574,7 @@ sub GetMessageBody {
                 $Self->{MessageBody} = '- no text message => see attachment -';
             }
 
-            # check it it's juat a html email (store it as attachment and add text/plain)
+            # check it it's a html-only email (store it as attachment and add text/plain)
             $Self->CheckMessageBody();
 
             # return message body
@@ -598,7 +585,7 @@ sub GetMessageBody {
                 $Self->{LogObject}->Log(
                     Priority => 'debug',
                     Message =>
-                        'No attachments returned from GetAttachments(), just a null attachment!?',
+                        'No attachments returned from GetAttachments(), just an empty attachment!?',
                 );
             }
 
@@ -733,12 +720,8 @@ sub PartsAttachments {
         return;
     }
 
-    # check if there is no recommended_filename -> add file-NoFilenamePartCounter
-    if ( !$Part->head()->recommended_filename() ) {
-        $Self->{NoFilenamePartCounter}++;
-        $PartData{Filename} = "file-$Self->{NoFilenamePartCounter}";
-    }
-    else {
+    # check if there is no recommended_filename or subject -> add file-NoFilenamePartCounter
+    if ( $Part->head()->recommended_filename() ) {
         $PartData{Filename}           = decode_mimewords( $Part->head()->recommended_filename() );
         $PartData{ContentDisposition} = $Part->head()->get('Content-Disposition');
         if ( $PartData{ContentDisposition} ) {
@@ -771,6 +754,37 @@ sub PartsAttachments {
         }
     }
 
+    # Guess the filename for nested messages (see bug#1970).
+    elsif ( $PartData{ContentType} eq 'message/rfc822' ) {
+        my ($SubjectString) = $Part->as_string =~ m/^Subject: ([^\n]*(\n[ \t][^\n]*)*)/m;
+        my $Subject;
+        foreach my $Decoded ( decode_mimewords($SubjectString) ) {
+            if ( $Decoded->[0] ) {
+                $Subject .= $Self->{EncodeObject}->Convert2CharsetInternal(
+                    Text  => $Decoded->[0],
+                    From  => $Decoded->[1] || 'us-ascii',
+                    Check => 1,
+                );
+            }
+        }
+
+        # trim whitespace
+        $Subject =~ s/^\s+|\n|\s+$//;
+        if ( length($Subject) > 246 ) {
+            $Subject = substr( $Subject, 0, 246 );
+        }
+
+        if ( $Subject eq '' ) {
+            $Self->{NoFilenamePartCounter}++;
+            $Subject = "Unbenannt-$Self->{NoFilenamePartCounter}";
+        }
+        $PartData{Filename} = $Subject . '.eml';
+    }
+    else {
+        $Self->{NoFilenamePartCounter}++;
+        $PartData{Filename} = "file-$Self->{NoFilenamePartCounter}";
+    }
+
     # parse/get Content-Id and Content-Location for html email attachments
     $PartData{ContentID}       = $Part->head()->get('Content-Id');
     $PartData{ContentLocation} = $Part->head()->get('Content-Location');
@@ -947,6 +961,6 @@ did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =head1 VERSION
 
-$Revision: 1.104.2.1 $ $Date: 2011-07-28 15:09:09 $
+$Revision: 1.107.2.1 $ $Date: 2012/11/29 12:42:28 $
 
 =cut
