@@ -1,8 +1,8 @@
 # --
 # Kernel/System/LinkObject.pm - to link objects
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.org/
 # --
-# $Id: LinkObject.pm,v 1.58.4.1 2012/07/01 23:09:45 mh Exp $
+# $Id: LinkObject.pm,v 1.58.4.3 2013/01/21 16:14:39 ub Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -19,7 +19,7 @@ use Kernel::System::Valid;
 use Kernel::System::CacheInternal;
 
 use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.58.4.1 $) [1];
+$VERSION = qw($Revision: 1.58.4.3 $) [1];
 
 =head1 NAME
 
@@ -457,13 +457,17 @@ sub LinkAdd {
 
     # check if link already exists in database
     return if !$Self->{DBObject}->Prepare(
-        SQL => 'SELECT source_object_id, source_key, state_id '
-            . 'FROM link_relation '
-            . 'WHERE ( ( source_object_id = ? AND source_key = ? '
-            . 'AND target_object_id = ? AND target_key = ? ) '
-            . 'OR ( source_object_id = ? AND source_key = ? '
-            . 'AND target_object_id = ? AND target_key = ? ) ) '
-            . 'AND type_id = ? ',
+        SQL => '
+            SELECT source_object_id, source_key, state_id
+            FROM link_relation
+            WHERE (
+                    ( source_object_id = ? AND source_key = ?
+                    AND target_object_id = ? AND target_key = ? )
+                OR
+                    ( source_object_id = ? AND source_key = ?
+                    AND target_object_id = ? AND target_key = ? )
+                )
+                AND type_id = ?',
         Bind => [
             \$Param{SourceObjectID}, \$Param{SourceKey},
             \$Param{TargetObjectID}, \$Param{TargetKey},
@@ -504,7 +508,7 @@ sub LinkAdd {
 
         return 1 if !$TypeData{Pointed};
         return 1 if $Existing{SourceObjectID} eq $Param{SourceObjectID}
-                && $Existing{SourceKey} eq $Param{SourceKey};
+            && $Existing{SourceKey} eq $Param{SourceKey};
 
         # log error
         $Self->{LogObject}->Log(
@@ -594,10 +598,11 @@ sub LinkAdd {
     );
 
     return if !$Self->{DBObject}->Do(
-        SQL => 'INSERT INTO link_relation '
-            . '(source_object_id, source_key, target_object_id, target_key, '
-            . 'type_id, state_id, create_time, create_by) '
-            . 'VALUES (?, ?, ?, ?, ?, ?, current_timestamp, ?)',
+        SQL => '
+            INSERT INTO link_relation
+            (source_object_id, source_key, target_object_id, target_key,
+            type_id, state_id, create_time, create_by)
+            VALUES (?, ?, ?, ?, ?, ?, current_timestamp, ?)',
         Bind => [
             \$Param{SourceObjectID}, \$Param{SourceKey},
             \$Param{TargetObjectID}, \$Param{TargetKey},
@@ -674,8 +679,10 @@ sub LinkCleanup {
 
     # delete the link
     return if !$Self->{DBObject}->Do(
-        SQL => 'DELETE FROM link_relation '
-            . 'WHERE state_id = ? AND create_time < ?',
+        SQL => '
+            DELETE FROM link_relation
+            WHERE state_id = ?
+                AND create_time < ?',
         Bind => [
             \$StateID, \$DeleteTime,
         ],
@@ -743,13 +750,17 @@ sub LinkDelete {
 
     # get the existing link
     return if !$Self->{DBObject}->Prepare(
-        SQL => 'SELECT source_object_id, source_key, target_object_id, target_key, state_id '
-            . 'FROM link_relation '
-            . 'WHERE ( source_object_id = ? AND source_key = ? '
-            . 'AND target_object_id = ? AND target_key = ? ) '
-            . 'OR ( source_object_id = ? AND source_key = ? '
-            . 'AND target_object_id = ? AND target_key = ? ) '
-            . 'AND type_id = ? ',
+        SQL => '
+            SELECT source_object_id, source_key, target_object_id, target_key, state_id
+            FROM link_relation
+            WHERE (
+                    ( source_object_id = ? AND source_key = ?
+                    AND target_object_id = ? AND target_key = ? )
+                OR
+                    ( source_object_id = ? AND source_key = ?
+                    AND target_object_id = ? AND target_key = ? )
+                )
+                AND type_id = ?',
         Bind => [
             \$Param{Object1ID}, \$Param{Key1},
             \$Param{Object2ID}, \$Param{Key2},
@@ -837,12 +848,16 @@ sub LinkDelete {
 
     # delete the link
     return if !$Self->{DBObject}->Do(
-        SQL => 'DELETE FROM link_relation '
-            . 'WHERE ( source_object_id = ? AND source_key = ? '
-            . 'AND target_object_id = ? AND target_key = ? ) '
-            . 'OR ( source_object_id = ? AND source_key = ? '
-            . 'AND target_object_id = ? AND target_key = ? ) '
-            . 'AND type_id = ? ',
+        SQL => '
+            DELETE FROM link_relation
+            WHERE (
+                    ( source_object_id = ? AND source_key = ?
+                    AND target_object_id = ? AND target_key = ? )
+                OR
+                    ( source_object_id = ? AND source_key = ?
+                    AND target_object_id = ? AND target_key = ? )
+                )
+                AND type_id = ?',
         Bind => [
             \$Param{Object1ID}, \$Param{Key1},
             \$Param{Object2ID}, \$Param{Key2},
@@ -1048,11 +1063,12 @@ sub LinkList {
 
     # get links where the given object is the source
     return if !$Self->{DBObject}->Prepare(
-        SQL => 'SELECT target_object_id, target_key, type_id '
-            . 'FROM link_relation '
-            . 'WHERE source_object_id = ? '
-            . 'AND source_key = ? '
-            . 'AND state_id = ? '
+        SQL => '
+            SELECT target_object_id, target_key, type_id
+            FROM link_relation
+            WHERE source_object_id = ?
+            AND source_key = ?
+            AND state_id = ? '
             . $TypeSQL,
         Bind => \@Bind,
     );
@@ -1092,12 +1108,12 @@ sub LinkList {
 
     # get links where the given object is the target
     return if !$Self->{DBObject}->Prepare(
-        SQL =>
-            'SELECT source_object_id, source_key, type_id '
-            . 'FROM link_relation '
-            . 'WHERE target_object_id = ? '
-            . 'AND target_key = ?  '
-            . 'AND state_id = ? '
+        SQL => '
+            SELECT source_object_id, source_key, type_id
+            FROM link_relation
+            WHERE target_object_id = ?
+                AND target_key = ?
+                AND state_id = ? '
             . $TypeSQL,
         Bind => \@Bind,
     );
@@ -1707,14 +1723,15 @@ sub TypeLookup {
 
             # insert the new type
             return if !$Self->{DBObject}->Do(
-                SQL => 'INSERT INTO link_type '
-                    . '(name, valid_id, create_time, create_by, change_time, change_by) '
-                    . 'VALUES (?, 1, current_timestamp, ?, current_timestamp, ?)',
+                SQL => '
+                    INSERT INTO link_type
+                    (name, valid_id, create_time, create_by, change_time, change_by)
+                    VALUES (?, 1, current_timestamp, ?, current_timestamp, ?)',
                 Bind => [ \$Param{Name}, \$Param{UserID}, \$Param{UserID} ],
             );
         }
 
-        # check the state id
+        # check the type id
         if ( !$TypeID ) {
             $Self->{LogObject}->Log(
                 Priority => 'error',
@@ -1775,8 +1792,10 @@ sub TypeGet {
 
     # ask the database
     return if !$Self->{DBObject}->Prepare(
-        SQL => 'SELECT id, name, create_time, create_by, change_time, change_by '
-            . 'FROM link_type WHERE id = ?',
+        SQL => '
+            SELECT id, name, create_time, create_by, change_time, change_by
+            FROM link_type
+            WHERE id = ?',
         Bind  => [ \$Param{TypeID} ],
         Limit => 1,
     );
@@ -2405,6 +2424,6 @@ did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =head1 VERSION
 
-$Revision: 1.58.4.1 $ $Date: 2012/07/01 23:09:45 $
+$Revision: 1.58.4.3 $ $Date: 2013/01/21 16:14:39 $
 
 =cut
