@@ -1,12 +1,12 @@
 # --
 # Kernel/System/PostMaster/Filter/MatchDBSource.pm - sub part of PostMaster.pm
-# Copyright (C) 2001-2008 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.org/
 # --
-# $Id: MatchDBSource.pm,v 1.13.2.1 2008/10/13 21:23:04 martin Exp $
+# $Id: MatchDBSource.pm,v 1.21.4.1 2013/02/07 14:01:06 ub Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::PostMaster::Filter::MatchDBSource;
@@ -17,7 +17,7 @@ use warnings;
 use Kernel::System::PostMaster::Filter;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.13.2.1 $) [1];
+$VERSION = qw($Revision: 1.21.4.1 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -28,7 +28,7 @@ sub new {
 
     $Self->{Debug} = $Param{Debug} || 0;
 
-    # get needed opbjects
+    # get needed objects
     for (qw(ConfigObject LogObject DBObject ParserObject)) {
         $Self->{$_} = $Param{$_} || die "Got no $_!";
     }
@@ -41,20 +41,29 @@ sub new {
 sub Run {
     my ( $Self, %Param ) = @_;
 
-    # get config options
-    my %Config = ();
-    my %Match  = ();
-    my %Set    = ();
+    # check needed stuff
+    for (qw(JobConfig GetParam)) {
+        if ( !$Param{$_} ) {
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            return;
+        }
+    }
 
+    # get all db filters
     my %JobList = $Self->{PostMasterFilter}->FilterList();
     for ( sort keys %JobList ) {
-        %Config = $Self->{PostMasterFilter}->FilterGet( Name => $_ );
+
+        # get config options
+        my %Config = $Self->{PostMasterFilter}->FilterGet( Name => $_ );
+        my %Match;
+        my %Set;
         if ( $Config{Match} ) {
             %Match = %{ $Config{Match} };
         }
         if ( $Config{Set} ) {
             %Set = %{ $Config{Set} };
         }
+        my $StopAfterMatch = $Config{StopAfterMatch} || 0;
         my $Prefix = '';
         if ( $Config{Name} ) {
             $Prefix = "Filter: '$Config{Name}' ";
@@ -63,15 +72,18 @@ sub Run {
         # match 'Match => ???' stuff
         my $Matched    = '';
         my $MatchedNot = 0;
-        for ( keys %Match ) {
-            if ( $Param{GetParam}->{$_} && $Match{$_} =~ /^EMAILADDRESS:(.*)$/ ) {
+        for ( sort keys %Match ) {
+
+            # match only email addresses
+            if ( defined $Param{GetParam}->{$_} && $Match{$_} =~ /^EMAILADDRESS:(.*)$/ ) {
                 my $SearchEmail    = $1;
                 my @EmailAddresses = $Self->{ParserObject}->SplitAddressLine(
                     Line => $Param{GetParam}->{$_},
                 );
                 my $LocalMatched;
-                for my $RawEmail (@EmailAddresses) {
-                    my $Email = $Self->{ParserObject}->GetEmailAddress( Email => $RawEmail );
+                for my $Recipients (@EmailAddresses) {
+                    my $Email = $Self->{ParserObject}->GetEmailAddress( Email => $Recipients );
+                    next if !$Email;
                     if ( $Email =~ /^$SearchEmail$/i ) {
                         $LocalMatched = $SearchEmail || 1;
                         if ( $Self->{Debug} > 1 ) {
@@ -91,7 +103,9 @@ sub Run {
                     $Matched = $LocalMatched;
                 }
             }
-            elsif ( $Param{GetParam}->{$_} && $Param{GetParam}->{$_} =~ /$Match{$_}/i ) {
+
+            # match string
+            elsif ( defined $Param{GetParam}->{$_} && $Param{GetParam}->{$_} =~ /$Match{$_}/i ) {
 
                 # don't lose older match values if more than one header is
                 # used for matching.
@@ -121,7 +135,7 @@ sub Run {
 
         # should I ignore the incoming mail?
         if ( $Matched && !$MatchedNot ) {
-            for ( keys %Set ) {
+            for ( sort keys %Set ) {
                 $Set{$_} =~ s/\[\*\*\*\]/$Matched/;
                 $Param{GetParam}->{$_} = $Set{$_};
                 $Self->{LogObject}->Log(
@@ -130,6 +144,16 @@ sub Run {
                         . "Set param '$_' to '$Set{$_}' (Message-ID: $Param{GetParam}->{'Message-ID'}) ",
                 );
             }
+
+            # stop after match
+            if ($StopAfterMatch) {
+                $Self->{LogObject}->Log(
+                    Priority => 'notice',
+                    Message  => $Prefix
+                        . "Stopped filter processing because of used 'StopAfterMatch' (Message-ID: $Param{GetParam}->{'Message-ID'}) ",
+                );
+                return 1;
+            }
         }
     }
     return 1;
