@@ -1,8 +1,8 @@
 # --
 # Kernel/System/Ticket/ArticleSearchIndex/RuntimeDB.pm - article search index backend runtime
-# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.org/
 # --
-# $Id: RuntimeDB.pm,v 1.12 2010-10-16 09:25:35 bes Exp $
+# $Id: RuntimeDB.pm,v 1.14.2.1 2013/01/16 13:38:03 marb Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -15,7 +15,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.12 $) [1];
+$VERSION = qw($Revision: 1.14.2.1 $) [1];
 
 sub ArticleIndexBuild {
     my ( $Self, %Param ) = @_;
@@ -71,8 +71,6 @@ sub _ArticleIndexQuerySQL {
     }
 
     # use also article table if required
-    my $SQL    = '';
-    my $SQLExt = '';
     for (
         qw(
         From To Cc Subject Body
@@ -83,13 +81,11 @@ sub _ArticleIndexQuerySQL {
     {
 
         if ( $Param{Data}->{$_} ) {
-            $SQL    = ', article art ';
-            $SQLExt = ' AND st.id = art.ticket_id';
-            last;
+            return ' INNER JOIN article art ON st.id = art.ticket_id ';
         }
     }
 
-    return $SQL, $SQLExt;
+    return '';
 }
 
 sub _ArticleIndexQuerySQLExt {
@@ -150,6 +146,9 @@ sub _ArticleIndexQuerySQLExt {
             # replace %% by % for SQL
             $Param{Data}->{$Key} =~ s/%%/%/gi;
 
+            # replace * with % (for SQL)
+            $Value =~ s/\*/%/g;
+
             # db quote
             $Value = $Self->{DBObject}->Quote( $Value, 'Like' );
 
