@@ -1,7 +1,9 @@
-#!/usr/bin/perl
+#!/usr/bin/perl -w
 # --
-# bin/otrs.CheckSum.pl - a tool to compare changes in an installation
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# bin/otrs.CheckSum.pl - a tool to compare changes in a installation
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
+# --
+# $Id: otrs.CheckSum.pl,v 1.9.4.1 2012/12/11 16:25:49 mg Exp $
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -15,20 +17,20 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 use strict;
 use warnings;
 
+# use ../ as lib location
 use File::Basename;
 use FindBin qw($RealBin);
 use lib dirname($RealBin);
-use lib dirname($RealBin) . '/Kernel/cpan-lib';
-use lib dirname($RealBin) . '/Custom';
 
-use vars qw($RealBin);
+use vars qw($VERSION $RealBin);
+$VERSION = qw($Revision: 1.9.4.1 $) [1];
 
 use Getopt::Std;
 use Digest::MD5 qw(md5_hex);
@@ -43,8 +45,8 @@ my %Compare;
 my %Opts;
 getopt( 'habd', \%Opts );
 if ( exists $Opts{h} || !keys %Opts ) {
-    print "otrs.CheckSum.pl - OTRS check sum\n";
-    print "Copyright (C) 2001-2013 OTRS AG, http://otrs.com/\n";
+    print "otrs.CheckSum.pl <Revision $VERSION> - OTRS check sum\n";
+    print "Copyright (C) 2001-2012 OTRS AG, http://otrs.org/\n";
     print
         "usage: otrs.CheckSum.pl -a create|compare [-b /path/to/ARCHIVE] [-d /path/to/framework]\n";
     exit 1;
@@ -63,14 +65,12 @@ else {
     $Archive = $Start . 'ARCHIVE';
 }
 
-my $Output;
-
 if ( $Action eq 'create' ) {
     print "Writing $Archive ...";
-    open( $Output, '>', $Archive ) || die "ERROR: Can't open: $Archive";    ## no critic
+    open( OUT, '>', $Archive ) || die "ERROR: Can't open: $Archive";
 }
 else {
-    open( my $In, '<', $Archive ) || die "ERROR: Can't open: $Archive";     ## no critic
+    open( my $In, '<', $Archive ) || die "ERROR: Can't open: $Archive";
     while (<$In>) {
         my @Row = split( /::/, $_ );
         chomp $Row[1];
@@ -88,15 +88,13 @@ for my $File ( sort keys %Compare ) {
 }
 if ( $Action eq 'create' ) {
     print " done.\n";
-    close $Output;
+    close OUT;
 }
 
 sub R {
     my $In = shift;
 
     my @List = glob("$In/*");
-
-    FILE:
     for my $File (@List) {
 
         # clean up directory name
@@ -105,13 +103,13 @@ sub R {
         # always stay in OTRS directory
         next FILE if $File !~ /^\Q$Start\E/;
 
-        # ignore source code directories, ARCHIVE file
-        next if $File =~ /Entries|Repository|Root|CVS|.git|ARCHIVE/;
+        # ignote cvs directories
+        next if $File =~ /Entries|Repository|Root|CVS|ARCHIVE/;
 
         # if it's a directory
         if ( -d $File ) {
             R($File);
-            next FILE;
+            next;
 
             # print "Directory: $File\n";
         }
@@ -125,21 +123,21 @@ sub R {
         $File =~ s/^\/(.*)$/$1/;
 
         # ignore directories
-        next      if $File =~ /^doc\//;
-        next FILE if $File =~ /^var\/tmp/;
-        next FILE if $File =~ /^var\/article/;
-        next FILE if $File =~ /js-cache/;
-        next FILE if $File =~ /css-cache/;
+        next if $File =~ /^doc\//;
+        next if $File =~ /^var\/tmp/;
+        next if $File =~ /^var\/article/;
+        next if $File =~ /js-cache/;
+        next if $File =~ /css-cache/;
 
         # next if not readable
         # print "File: $File\n";
-        open( my $In, '<', $OrigFile ) || die "ERROR: $!";    ## no critic
-        my $DigestGenerator = Digest::MD5->new();
-        $DigestGenerator->addfile($In);
-        my $Digest = $DigestGenerator->hexdigest();
+        open( my $In, '<', $OrigFile ) || die "ERROR: $!";
+        my $ctx = Digest::MD5->new;
+        $ctx->addfile($In);
+        my $Digest = $ctx->hexdigest();
         close $In;
         if ( $Action eq 'create' ) {
-            print $Output $Digest . '::' . $File . "\n";
+            print OUT $Digest . '::' . $File . "\n";
         }
         else {
             if ( !$Compare{$File} ) {
